clear
set more off

********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************

/*PREAMBLE*/

global desktop C:\Users\User\Dropbox\Research\Working Papers\War in India\EJ Final Submission\MS 20210009 final files\3 replication package\
	/*
	Change this directory to match your own. 
	Ensure all replication files are in a sub-folder named "Replication\Data". 
	Ensure there is an empty folder named "Replication\Output". 
	*/

global maps $desktop\Data\
global dofiles $desktop\Data\
global cleandata $desktop\Data\
global rawdata $desktop\Data\
global output $desktop\Output\

********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************

/*TABLES IN TEXT*/

********************************************************************************
********************************************************************************
********************************************************************************

/*Table 1: Main Results*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store main1
	
xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store main2

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store main3
	
esttab main1 main2 main3 using table1.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

/*Compute within R-squared values*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

cap erase table1_withinr2.xml
cap erase table1_withinr2.txt
reghdfe lnlights_001 Land_250_1757 lnpdgpd1990, noabsorb vce(robust) 
	outreg2 using table1_withinr2, addstat(Within R2,e(r2_a_within)) keep(Land_250_1757) excel nocon label append
reghdfe lnlights_001 Land_250_1757 lnpdgpd1990, a(state) vce(robust) 
	outreg2 using table1_withinr2, addstat(Within R2,e(r2_a_within)) keep(Land_250_1757) excel nocon label append
reghdfe lnlights_001 Land_250_1757 lnpdgpd1990 `controls_gis', a(state) vce(robust)
	outreg2 using table1_withinr2, addstat(Within R2,e(r2_a_within)) keep(Land_250_1757) excel nocon label append
cap erase table1_withinr2.txt

/*
We have manually added the following after the "R2" line in Tex file:

Within \(R^{2}\) & 0.597 & 0.574 & 0.617 \\
*/

********************************************************************************
********************************************************************************
********************************************************************************

/*Table 2: IV*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"
		
/*First stage*/

xi: reg Land_250_1757 instrument lnpdgpd1990, r beta
	estadd ysumm
	estimates store iv_firststage1

xi: reg Land_250_1757 instrument lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estimates store iv_firststage2

xi: reg Land_250_1757 instrument lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estimates store iv_firststage3
	
esttab iv_firststage1 iv_firststage2 iv_firststage3 using table2a.tex, ///
	replace fragment keep(instrument) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(instrument "Proximity to Khyber Pass") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

/*Second stage*/

xi: ivreg2 lnlights_001 (Land_250_1757=instrument) lnpdgpd1990, r ffirst
	estadd ysumm
	estimates store iv_secondstage1
	
xi: ivreg2 lnlights_001 (Land_250_1757=instrument) lnpdgpd1990 i.state_gadm, r ffirst
	estadd ysumm
	estimates store iv_secondstage2

xi: ivreg2 lnlights_001 (Land_250_1757=instrument) lnpdgpd1990 i.state_gadm `controls_gis', r ffirst
	estadd ysumm
	estimates store iv_secondstage3

esttab iv_secondstage1 iv_secondstage2 iv_secondstage3 using table2b.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("archi2p Anderson-Rubin p-value" "widstat Kleibergen-Paap Wald rk F-statistic") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*Table 3: Pre-Colonial-Era State-Making*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

/*Make sample equivalent to benchmark sample*/

xi: reg lnlights_001 Land_250_1526 lnpdgpd1990, r beta
	keep if e(sample)

xi: reg plateVIA4_any Land_250_1757 `controls_gis' i.state_gadm lnhyde1500, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate21

xi: reg babur Land_250_1526 `controls_gis' i.state_gadm lnhyde1500, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate22

xi: reg akbar Land_250_1556 `controls_gis' i.state_gadm lnhyde1500, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate23

xi: reg aurangzeb Land_250_1658 `controls_gis' i.state_gadm lnhyde1500, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate24
	
esttab initialstate21 initialstate22 initialstate23 initialstate24 using table3.tex, ///
	replace fragment keep(Land_250_1757 Land_250_1526 Land_250_1556 Land_250_1658) ///
	b(3) se(3) posthead(\cmidrule(lr){2-5}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure (benchmark)" ///
	Land_250_1526 "Pre-colonial conflict exposure (1000-1526)" ///
	Land_250_1556 "Pre-colonial conflict exposure (1000-1556)" ///
	Land_250_1658 "Pre-colonial conflict exposure (1000-1658)") ///
	indicate("Population density = lnhyde1500" "State FE = *state*" "Geographic controls = `controls_gis'")	

/*
To reduce # of rows in table, we have manually collapsed conflict variables to "Pre-colonial conflict exposure" in Tex file; 
The table notes specify different years for each column
*/

********************************************************************************
********************************************************************************
********************************************************************************

/*Table 4: Colonial Fiscal Development*/

cd "$output"
use "$cleandata\conflictexposure_native.dta", clear

local controls_gis "latitude longitude altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlandrevpa Land_250_1757 `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial21

xi: reg lnlandrevpc Land_250_1757 `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial22
	
xi: reg lnlandrevpaBI Land_250_1757 `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial23

xi: reg lnlandrevpcBI Land_250_1757 `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial24

xi: reg lnlandrevpaNSII Land_250_1757 `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial25

xi: reg lnlandrevpcNSII Land_250_1757 `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial26

use "$cleandata\leetaxdata.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"

xi: reg lntaxpa Land_250_1757 `controls_gis' i.state_gadm lnhydepd1930, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial27

xi: reg lntaxpc Land_250_1757 `controls_gis' i.state_gadm lnhydepd1930, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial28

esttab colonial21 colonial22 colonial23 colonial24 colonial25 colonial26 colonial27 colonial28 using table4.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-9}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = _cons" "State FE = *state*" "Geographic controls = `controls_gis'")		

********************************************************************************
********************************************************************************
********************************************************************************

/*Table 5: Colonial and Post-Colonial Conflict*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg Land_250_1758_1839 Land_250_1757 lnhyde1750 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict1

xi: reg Conflict_250_1758_1839 Land_250_1757 lnhyde1750 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict2

xi: reg Land_250_1840_1946 Land_250_1757 lnhyde1850 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict3

xi: reg Conflict_250_1840_1946 Land_250_1757 lnhyde1850 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict4

xi: reg Land_250_1947 Land_250_1757 lnhyde1950 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store postcolonialconflict1

xi: reg Conflict_250_1947 Land_250_1757 lnhyde1950 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store postcolonialconflict2

esttab colonialconflict1 colonialconflict2 colonialconflict3 colonialconflict4 postcolonialconflict1 postcolonialconflict2 using table5.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-7}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure" Land_250_1758_1839) ///
	indicate("Population density = _cons" "State FE = *state*" "Geographic controls = `controls_gis'")	
	
********************************************************************************
********************************************************************************
********************************************************************************

/*Table 6: Conflict and Post-Colonial Political Violence*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

/*Make sample equivalent to benchmark sample*/

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, r beta
	keep if e(sample)

xi: reg fatalities2 Land_250_1757 `controls_gis' i.state_gadm lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store polviolence1

use "$cleandata\mukherjeedata.dta", clear

rename Land_250_1757_collapsed Land_250_1757

local controls_gis "latitude_gadm_collapsed longitude_gadm_collapsed altit_collapsed nprug_collapsed precip_collapsed ramank_collapsed dryrice_collapsed wrice_collapsed wheat_collapsed kmal_collapsed"

xi: reg maoist_BDI_2003 Land_250_1757 lnpdgpd1990_collapsed i.state `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store polviolence2
	
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg ethfrac Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store polviolence3

xi: reg relfrac_census Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store polviolence4

esttab polviolence1 polviolence2 polviolence3 polviolence4 using table6.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-5}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")		

/*we have manually changed "Geographic controls" to "Yes" in column 2 in Tex file*/

********************************************************************************
********************************************************************************
********************************************************************************

/*Table 7: Irrigation Infrastructure*/

cd "$output"
use "$cleandata\vdsadataclean.dta", clear
local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"

xi: reg prop_canal_312 Land_250_1757 lnhyde1900 i.statename `controls_gis' if lnlights_001!=. & year==1966, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store aginvest1

cd "$output"
use "$cleandata\exposure_bi.dta", clear

rename Land_250_1757_collapsed Land_250_1757

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"

xi: reg irr_g_avg2 Land_250_1757 lnhyde1950 i.state `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store aginvest2

xi: reg lyld_avg Land_250_1757 lnhyde1950 i.state `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store aginvest3

use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

/*Make sample equivalent to benchmark sample*/

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, r beta
keep if e(sample)==1

xi: reg sh_nonag Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store aginvest4

esttab aginvest1 aginvest2 aginvest3 aginvest4 using table7.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-5}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = _cons" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*Table 8: Literacy*/

cd "$output"
use "$cleandata\literacy1881.dta", clear
local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"

xi: reg literacy81 Land_250_1757 lnhyde1850 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store literacy1

cd "$output"
use "$cleandata\literacy1921.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if province21=="Andaman and Nicobars"

xi: reg literacy21 Land_250_1757 lnhyde1900 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store literacy2

cd "$output"
use "$cleandata\exposure_bi_literacy.dta", clear

rename Land_250_1757_collapsed Land_250_1757

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"

xi: reg lrate_avg2 Land_250_1757 lnhyde1950 i.state `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store literacy3
	
use "$cleandata\devcensuswgis.dta", clear

rename Land_250_1757_collapsed Land_250_1757

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if areaname=="Nicobars" | areaname=="South Andaman" | areaname=="North  & Middle Andaman" | areaname=="Lakshadweep"

xi: reg cinfo324_2011 Land_250_1757 lnpopd2011 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store literacy4

esttab literacy1 literacy2 literacy3 literacy4 using table8.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-5}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = _cons" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*Table 9: Education*/

cd "$output"
use "$cleandata\bi_educ_exposure.dta", clear

rename Land_250_1757_collapsed Land_250_1757

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"

xi: reg pprimary812 Land_250_1757 lnhyde1950 i.state `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store education1

xi: reg phigh812 Land_250_1757 lnhyde1950 i.state `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store education2
	
use "$cleandata\bi_infmort_exposure.dta", clear

rename Land_250_1757_collapsed Land_250_1757

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"

xi: reg infmort Land_250_1757 lnhyde1950 i.state `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store education3
	
esttab education1 education2 education3 using table9.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = _cons" "State FE = *state*" "Geographic controls = `controls_gis'")

********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************

/*FIGURES IN TEXT*/

********************************************************************************
********************************************************************************
********************************************************************************

/*Figure 1: Pre-Colonial Conflict Exposure and Luminosity: India*/

/*Panels (a) and (b): Conflict Exposure and Luminosity*/

*** Prepare map
cd "$maps"
cap erase james1.dta				
cap erase jamesco1.dta
shp2dta using IND_adm2, data(james1) coord(jamesco1) genid(geoid)
use james1.dta, clear
cd "$cleandata"
rename NAME_1 state_gadm
rename NAME_2 district_gadm
keep state_gadm district_gadm geoid latitude longitude
sort state_gadm district_gadm 
saveold jamestemp, replace

*** Merge data to map
use "$cleandata\conflictexposure.dta", clear
sort state_gadm district_gadm 
merge state_gadm district_gadm using jamestemp
tab _merge
drop _merge
erase jamestemp.dta

***Draw maps
foreach var of varlist lnlights_001 Land_250_1757 {
	cd "$maps"
	cap local lvar : variable label `var'
	cap spmap `var' using "jamesco1", id(geoid) ///
	legend(pos(5) region(c(white))) title("`lvar'") clm(q) cln(10) fc(Greys2) 
	cd "$output"
	cap graph export map_`var'.png, as(png) width(2500) replace
	cap graph close graph
}

/*Panel (c): Correlation*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

reg lnlights_001 lnpdgpd1990
	predict lightsresid, resid
	
reg Land_250_1757 lnpdgpd1990
	predict conflictresid, resid
	
twoway (lfit lightsresid conflictresid, lpat(solid) lw(medthick)) ///
	(scatter lightsresid conflictresid, msym(none) mlab(district_gadm) mlabpos(0)) ///
	, scheme(lean1) legend(off) ytitle("Luminosity (Residuals)") xtitle("Pre-Colonial Conflict Exposure (Residuals)")
cap graph export correlation.png, as(png) width(2500) replace

********************************************************************************
********************************************************************************
********************************************************************************

/*Figure 2: Pre-Colonial Conflict Exposure and Luminosity: Uttar Pradesh*/

*** Prepare map
cd "$maps"
cap erase james1.dta				
cap erase jamesco1.dta
shp2dta using IND_adm2, data(james1) coord(jamesco1) genid(geoid)
use james1.dta, clear
cd "$cleandata"
rename NAME_1 state_gadm
rename NAME_2 district_gadm
keep state_gadm district_gadm geoid latitude longitude
sort state_gadm district_gadm 
saveold jamestemp, replace

*** Merge data to map
use "$cleandata\conflictexposure.dta", clear
sort state_gadm district_gadm 
merge state_gadm district_gadm using jamestemp
tab _merge
drop _merge
erase jamestemp.dta

***Draw maps
foreach var of varlist lnlights_001 Land_250_1757 {
	cd "$maps"
	cap local lvar : variable label `var'
	cap spmap `var' using "jamesco1" if state_gadm=="Uttar Pradesh", id(geoid) ///
	legend(pos(2) region(c(white))) title("`lvar'") clm(q) cln(10) fc(Greys2) 
	cd "$output"
	cap graph export map_UP_`var'.png, as(png) width(2500) replace
	cap graph close graph
}

********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************

/*TABLES IN APPENDIX*/

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.1: Summary Statistics: Main Analysis*/

use "$cleandata\conflictexposure.dta", clear

keep lnlights_001 Land_250_1757 Land_250_1758_1839 ///
Land_250_1840_1946 Land_250_1947 ///
plateVIA4_any babur akbar aurangzeb ///
instrument lnpdgpd1990 latitude_gadm longitude_gadm altit nprug /// 
precip ramank dryrice wrice wheat kmal 

label var Land_250_1757 "Pre-colonial conflict exposure, 1000-1757"
label var Land_250_1758_1839 "Colonial conflict exposure, 1758-1839"
label var Land_250_1840_1946 "Colonial conflict exposure, 1840-1946"
label var Land_250_1947 "Post-colonial conflict exposure, 1947-2010"
label var lnlights_001 "ln(0.01+Luminosity)"
label var instrument "Khyber proximity"
label var babur "Districts incorporated by Babur"
label var akbar "Districts incorporated by Akbar"
label var aurangzeb "Districts incorporated by Aurangzeb"
label var plateVIA4_any "Important Mughal sites"

eststo clear
estpost sum lnlights_001 Land_250_1757 Land_250_1758_1839 ///
Land_250_1840_1946 Land_250_1947 instrument  ///
lnpdgpd1990 latitude_gadm longitude_gadm altit nprug /// 
precip ramank dryrice wrice wheat kmal plateVIA4_any babur ///
akbar aurangzeb

cd "$output"			
esttab using sumstats_main1.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************
	
use "$cleandata\conflictexposure_native.dta", clear

label var lnlandrevpa "Ln(Tax/Area), 1881 (All)"
label var lnlandrevpaBI "Ln(Tax/Area), 1881 (British India)"
label var lnlandrevpaNSII "Ln(Tax/Area), 1881 (Princely states)"
label var lnlandrevpc "Ln(Tax/Person), 1881 (All)"
label var lnlandrevpcBI "Ln(Tax/Person), 1881 (British India)"
label var lnlandrevpcNSII "Ln(Tax/Person), 1881 (Princely states)"

eststo clear
estpost sum lnlandrevpa lnlandrevpc lnlandrevpaBI ///
lnlandrevpcBI lnlandrevpaNSII lnlandrevpcNSII

cd "$output"
esttab using sumstats_main2.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************
	
use "$cleandata\leetaxdata.dta", clear

label var lntaxpa "Ln(Tax/Area), 1931 (British India)"
label var lntaxpc "Ln(Tax/Person), 1931 (British India)"

eststo clear
estpost sum lntaxpa lntaxpc

cd "$output"
esttab using sumstats_main3.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles	

********************************************************************************

use "$cleandata\conflictexposure.dta", clear

keep fatalities2 

label var fatalities2 "Political violence, 2015-18 (hundreds of fatalities)"

eststo clear
estpost sum fatalities2

cd "$output"			
esttab using sumstats_main4.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles
	
********************************************************************************

use "$cleandata\mukherjeedata.dta", clear
label var maoist_BDI_2003  "Maoist control, 2003"

eststo clear
estpost sum maoist_BDI_2003

cd "$output"			
esttab using sumstats_main5.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles
	
********************************************************************************

use "$cleandata\conflictexposure.dta", clear

keep ethfrac relfrac_census 

label var ethfrac "Linguistic fractionalization, 2001"
label var relfrac_census "Religious fractionalization, 2001" 

eststo clear
estpost sum ethfrac relfrac_census 

cd "$output"			
esttab using sumstats_main6.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles
	
********************************************************************************

use "$cleandata\vdsadataclean.dta", clear
keep if year == 1966

eststo clear
estpost sum prop_canal_312 

cd "$output"			
esttab using sumstats_main7.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************
 	
use "$cleandata\exposure_bi.dta", clear

label var lyld_avg "Ln(Yield), 1956-87"

eststo clear
estpost sum irr_g_avg2 lyld_avg


cd "$output"
esttab using sumstats_main8.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles	
	
********************************************************************************

use "$cleandata\conflictexposure.dta", clear

keep sh_nonag

label var sh_nonag "\%Non-Agriculture, 2011"

eststo clear
estpost sum sh_nonag

cd "$output"
esttab using sumstats_main9.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles	

********************************************************************************

use "$cleandata\literacy1881.dta", clear
keep literacy81 lnhyde1850 

label var literacy81 "\%Literacy, 1881"  

eststo clear
estpost sum literacy81 

cd "$output"
esttab using sumstats_main10.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************

use "$cleandata\literacy1921.dta", clear
keep literacy21 lnhyde1900 

label var literacy21 "\%Literacy, 1921" 

eststo clear
estpost sum literacy21 

cd "$output"
esttab using sumstats_main11.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************

use "$cleandata\exposure_bi_literacy.dta", clear
keep lrate_avg2 lnhyde1950 

label var lrate_avg2 "\%Literacy, 1961-91"

eststo clear
estpost sum lrate_avg2 

cd "$output"
esttab using sumstats_main12.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************

use "$cleandata\devcensuswgis.dta", clear
gen lnpopd2001=ln(dinfo136_2001)
keep cinfo324_2011 lnpopd2011 

label var cinfo324_2011 "\%Literacy, 2011"

eststo clear
estpost sum cinfo324_2011 

cd "$output"
esttab using sumstats_main13.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************

use "$cleandata\bi_educ_exposure.dta", clear

keep pprimary812 phigh812

label var pprimary812 "\%Primary school, 1981"
label var phigh812 "\%High school, 1981"

eststo clear
estpost sum pprimary812 phigh812 

cd "$output"
esttab using sumstats_main14.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************
	
use "$cleandata\bi_infmort_exposure.dta", clear

keep infmort 

label var infmort "\%Infant mortality, 1991"

eststo clear
estpost sum infmort

cd "$output"
esttab using sumstats_main15.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles
	
********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.2: Summary Statistics: Appendix Analysis*/

use "$cleandata\cells.dta", clear

label var Land_250_1757 "Pre-colonial conflict exposure, 1000-1757 (grid cell)"
label var lnlights_001 "Ln(0.01+Luminosity) (grid cell)"

eststo clear
estpost sum lnlights_001

cd "$output"
esttab using sumstats_appendix1.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************

use "$cleandata\tehsildata.dta", clear

label var Land_250_1757 "Pre-colonial conflict exposure, 1000-1757 (sub-district)"
label var lnlights_001 "Ln(0.01+Luminosity) (sub-district)"

eststo clear
estpost sum lnlights_001

cd "$output"
esttab using sumstats_appendix2.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************

use "$cleandata\conflictexposure.dta", clear

keep lnviirs_001

label var lnviirs_001 " Ln(0.01+Luminosity) (VIIRS)"

eststo clear
estpost sum lnviirs_001

cd "$output"
esttab using sumstats_appendix3.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************

use "$cleandata\conflictexposure.dta", clear
 
label var lnlights "Ln(1+Luminosity)"
label var lights "Luminosity (levels)"
label var lights_ihs "Luminosity (IHS)"

eststo clear
estpost sum lnlights lights lights_ihs 

cd "$output"
esttab using sumstats_appendix4.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************

cd "$output"
use "$cleandata\districtgdp.dta", clear

label var lndgdppc_avg "Ln(GDP per capita)"

eststo clear
estpost sum lndgdppc_avg	
	
cd "$output"
esttab using sumstats_appendix5.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles
	
********************************************************************************

use "$cleandata\cells.dta", clear

label var Land_250_1757 "Pre-colonial conflict exposure, 1000-1757 (grid cell)"
label var lnlights_001 "Ln(0.01+Luminosity) (grid cell)"

eststo clear
estpost sum Land_250_1757 

cd "$output"
esttab using sumstats_appendix6.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************

use "$cleandata\tehsildata.dta", clear

label var Land_250_1757 "Pre-colonial conflict exposure, 1000-1757 (sub-district)"
label var lnlights_001 "Ln(0.01+Luminosity) (sub-district)"

eststo clear
estpost sum Land_250_1757 

cd "$output"
esttab using sumstats_appendix7.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************

use "$cleandata\conflictexposure.dta", clear

keep Conflict_250_1757 Siege_250_1757 Oneday_250_1757_ld  ///
Multiday_250_1757_ld Land_250_1757_int Land_5000_1757 ///
Land_250_1500_1757 Land_250_1757_jc Land_250_1757_jcn ///
Land_250_annex 

label var Conflict_250_1757 "Pre-colonial conflict exposure (all)"
label var Siege_250_1757 "Pre-colonial conflict exposure (sieges)"
label var Oneday_250_1757_ld "Pre-colonial conflict exposure (single-day)" 
label var Multiday_250_1757_ld "Pre-colonial conflict exposure (multi-day)"
label var Land_250_1757_int "Pre-colonial conflict exposure (internal)"
label var Land_5000_1757 "Pre-colonial conflict exposure (5,000 km cutoff)"
label var Land_250_1500_1757 "Pre-colonial conflict exposure (1500-1757)"
label var Land_250_1757_jc "Pre-colonial conflict exposure (plus Clodfelter)" 
label var Land_250_1757_jcn "Pre-colonial conflict exposure (plus Clodfelter and Narvane)" 
label var Land_250_annex "Pre-colonial conflict exposure (running end-date)"

eststo clear
estpost sum Conflict_250_1757 Siege_250_1757 Oneday_250_1757_ld  ///
Multiday_250_1757_ld Land_250_1757_int Land_5000_1757 ///
Land_250_1500_1757 Land_250_1757_jc Land_250_1757_jcn ///
Land_250_annex 

cd "$output"			
esttab using sumstats_appendix8.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles
	
********************************************************************************

use "$cleandata\conflictexposure.dta", clear
append using "$cleandata\bgdpak.dta"

keep Land_250_1757

label var Land_250_1757 "Pre-colonial conflict exposure (plus Bangladesh and Pakistan)"

eststo clear
estpost sum Land_250_1757 

cd "$output"			
esttab using sumstats_appendix9.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles

********************************************************************************

use "$cleandata\conflictexposure.dta", clear

keep conflictsbycapital Land_250_1757_capital ///
conflictsbyactor chull_title 

label var conflictsbycapital "Pre-colonial conflict exposure \\ (\# conflicts in district of state capital)"
label var Land_250_1757_capital "Pre-colonial conflict exposure \\ (by location of participant capitals)"
label var conflictsbyactor "Pre-colonial conflict exposure \\ (\# conflicts in convex hull, by participant)"
label var chull_title "Pre-colonial conflict exposure \\ (\# conflicts in convex hull, by group)"

eststo clear
estpost sum conflictsbycapital Land_250_1757_capital ///
conflictsbyactor chull_title 

cd "$output"			
esttab using sumstats_appendix10.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles
	
********************************************************************************

use "$cleandata\conflictexposure.dta", clear

keep plateII2a_neolithic plateII2b_chalcolithic plateIIID4_classical ///
plateIV4a_religious lnipop1000 lnd_coast lnd_bord ///
river irrpot cvdelrain lndp_petroleum_s lndp_diamprim_s lndp_gem_s ///
lndp_goldplacer_s pctforest ///
britdum 

label var plateII2a_neolithic "Neolithic settlements"
label var plateII2b_chalcolithic "Chalcolithic settlments"
label var plateIIID4_classical "Cultural sites (300-700 CE)"
label var plateIV4a_religious "Cultural sites (8th-12th centuries)"
label var lnipop1000 "Ln(1+Urban population in 1000)"
label var lnd_coast "Ln(1+Distance to coast)"
label var lnd_bord "Ln(1+Distance to border)"
label var river "River dummy"
label var irrpot "Irrigation potential"
label var cvdelrain "Rainfall variation"
label var lndp_petroleum_s "Ln(1+Distance to petroleum)"
label var lndp_diamprim_s "Ln(1+Distance to diamonds)"
label var lndp_gem_s "Ln(1+Distance to gems)"
label var lndp_goldplacer_s "Ln(1+Distance to gold)" 
label var pctforest "\%Forest"
label var britdum "Direct rule"

eststo clear
estpost sum plateII2a_neolithic plateII2b_chalcolithic plateIIID4_classical ///
plateIV4a_religious lnipop1000 lnd_coast lnd_bord ///
river irrpot cvdelrain lndp_petroleum_s lndp_diamprim_s lndp_gem_s ///
lndp_goldplacer_s pctforest ///
britdum 

cd "$output"
esttab using sumstats_appendix11.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles
	
********************************************************************************

use "$cleandata\biclean.dta", clear

label var p_nland100 "\%Non-landlord"

eststo clear
estpost sum p_nland100

cd "$output"
esttab using sumstats_appendix12.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles		
	

********************************************************************************

use "$cleandata\conflictexposure.dta", clear

keep rryear ///
	yearsmuslim sh_muslim cpctsc011 cpctst011 ganges ///
	ah1 ///
	d5_delhi d5_mumbai d5_kolk d5_chen d5_bang ///
	tr17c unescosilkroad mport ///
	instrument_suratrsq instrument_kodungrsq instrument_goarsq ///
	instrument_calicutrsq instrument_bombayrsq ///
	instrument_cd1 instrument_cd2 instrument_cd3 instrument_cd4 ///
	
*Rescale
replace rryear=rryear/1000
label var rryear "Year of Railroad/1000"

*Include districts with no colonial railroad
*Recode railroad year
gen norr=rryear==.
label var norr "No Railroad by 1934"
recode rryear (.=0)

label var yearsmuslim "Duration of Muslim rule"
label var sh_muslim "Muslim share"
lab var cpctsc011 "Scheduled Caste share" 
lab var cpctst011 "Scheduled Tribe share"
label var ganges "Ganges River"
lab var ah1 "Asian highway"
label var tr17c "Historical trade route"
label var unescosilkroad "Silk Road site"
label var mport "Medieval trade port"
label var instrument_suratrsq "Surat proximity" 
label var instrument_kodungrsq "Kodungallur proximity"
label var instrument_goarsq "Goa proximity"
label var instrument_calicutrsq "Calicut proximity" 
label var instrument_bombayrsq "Bombay proximity"
label var instrument_cd1 "Khyber proximity (linear slope)" 
label var instrument_cd2 "Khyber proximity (squared slope)"
label var instrument_cd3 "Khyber proximity (linear ruggedness)"
label var instrument_cd4 "Khyber proximity (HMI)"

eststo clear
estpost sum rryear ///
	norr yearsmuslim sh_muslim cpctsc011 cpctst011 ganges ///
	ah1 d5_delhi d5_mumbai d5_kolk d5_chen d5_bang ///
	tr17c unescosilkroad mport ///
	instrument_suratrsq instrument_kodungrsq instrument_goarsq ///
	instrument_calicutrsq instrument_bombayrsq ///
	instrument_cd1 instrument_cd2 instrument_cd3 instrument_cd4 

cd "$output"
esttab using sumstats_appendix13.tex, fragment replace ///
	cells((mean(label(\multicolumn{1}{c}{}) fmt(2)) ///
	sd(label(\multicolumn{1}{c}{}) fmt(2)) ///
	min(label(\multicolumn{1}{c}{}) fmt(2)) ///
	max(label(\multicolumn{1}{c}{}) fmt(2)) ///
	count(label(\multicolumn{1}{c}{}) fmt(0)))) ///
	label booktabs nonum noobs ///
	nolines nomtitles
		
********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.3: Unit of Analysis: Grid Cell or Sub-District (i.e. Tehsil)*/

cd "$output"
use "$cleandata\cells.dta", clear

local controls_gis "latitude_gadm longitude_gadm altitude nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store gridcellunit1
	
xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store gridcellunit2

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store gridcellunit3
	
use "$cleandata\tehsildata.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

egen districtid=group(state_gadm district_gadm)

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, cl(districtid)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store tehsil1
	
xi: reg lnlights_001 Land_250_1757 i.state_gadm lnpdgpd1990, cl(districtid)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store tehsil2

xi: reg lnlights_001 Land_250_1757 i.state_gadm `controls_gis' lnpdgpd1990, cl(districtid)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store tehsil3

esttab gridcellunit1 gridcellunit2 gridcellunit3 tehsil1 tehsil2 tehsil3 using gridcellunit.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-7}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.4: Alternative Specifications of Dependent Variable*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights Land_250_1757 lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store lnlights1

xi: reg lnlights Land_250_1757 lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store lnlights2

xi: reg lnlights Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store lnlights3

xi: reg lights Land_250_1757 lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store lights1

xi: reg lights Land_250_1757 lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store lights2

xi: reg lights Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store lights3
	
xi: reg lights_ihs Land_250_1757 lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store lights_ihs1

xi: reg lights_ihs Land_250_1757 lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store lights_ihs2

xi: reg lights_ihs Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store lights_ihs3

esttab lnlights1 lnlights2 lnlights3 lights1 lights2 lights3 lights_ihs1 lights_ihs2 lights_ihs3 using altDVspecs.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-10}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.5: Population Density Polynomials*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

gen poppoly1=lnpdgpd1990
gen poppoly2=lnpdgpd1990^2
gen poppoly3=lnpdgpd1990^3

xi: reg lnlights_001 Land_250_1757 poppoly1 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store poppoly1

xi: reg lnlights_001 Land_250_1757 poppoly1 poppoly2 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store poppoly2

xi: reg lnlights_001 Land_250_1757 poppoly1 poppoly2 poppoly3 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store poppoly3
	
esttab poppoly1 poppoly2 poppoly3 using poppoly.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("State FE = *state*" "Geographic controls = `controls_gis'")	

/*
We have manually added the following above the "State FE" line in Tex file:

\addlinespace
Order of polynomial (population density) & 1 & 2 & 3 \\
*/

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.6: No Population Density Control*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store nopopdens1
	
xi: reg lnlights_001 Land_250_1757 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store nopopdens2

xi: reg lnlights_001 Land_250_1757 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store nopopdens3
	
esttab nopopdens1 nopopdens2 nopopdens3 using nopopdens.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("State FE = *state*" "Geographic controls = `controls_gis'")	

/*
We have manually added the following above the "State FE" line in Tex file:

\addlinespace
Population density & No & No & No \\
*/

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.7: Historical Population Density Control*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757 lnhyde1000, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store popdens10001
	
xi: reg lnlights_001 Land_250_1757 lnhyde1000 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store popdens10002

xi: reg lnlights_001 Land_250_1757 lnhyde1000 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store popdens10003
	
esttab popdens10001 popdens10002 popdens10003 using popdens1000.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnhyde1000" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.8: Grid Cell Fixed Effects*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store gridcellFE1

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.squareid, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store gridcellFE2

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.squareid `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store gridcellFE3

esttab gridcellFE1 gridcellFE2 gridcellFE3 using gridcellFE.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "Grid cell FE = *squareid*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.9: Conley Spatial Standard Errors*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: acreg lnlights_001 Land_250_1757 i.state_gadm `controls_gis' lnpdgpd1990, spatial latitude(latitude_gadm) longitude(longitude_gadm) dist(250)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store conley1
	
xi: acreg lnlights_001 Land_250_1757 i.state_gadm `controls_gis' lnpdgpd1990, spatial latitude(latitude_gadm) longitude(longitude_gadm) dist(500)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store conley2

xi: acreg lnlights_001 Land_250_1757 i.state_gadm `controls_gis' lnpdgpd1990, spatial latitude(latitude_gadm) longitude(longitude_gadm) dist(750)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store conley3

xi: acreg lnlights_001 Land_250_1757 i.state_gadm `controls_gis' lnpdgpd1990, spatial latitude(latitude_gadm) longitude(longitude_gadm) dist(1000)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store conley4

xi: acreg lnlights_001 Land_250_1757 i.state_gadm `controls_gis' lnpdgpd1990, spatial latitude(latitude_gadm) longitude(longitude_gadm) dist(1250)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store conley5

xi: acreg lnlights_001 Land_250_1757 i.state_gadm `controls_gis' lnpdgpd1990, spatial latitude(latitude_gadm) longitude(longitude_gadm) dist(1500)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store conley6

esttab conley1 conley2 conley3 conley4 conley5 conley6 using conley.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-7}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

/*
We have manually added the following above the "Population density" line in Tex file:

\addlinespace
Cutoff distance (km) & 250 & 500 & 750 & 1000 & 1250 & 1500 \\
*/

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.10: Alternative Standard Errors*/

cd "$dofiles"
cap program drop x_ols
do x_ols.ado

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"
 
/*Bootstrap options*/

local seed = 75974
local reps = 9999
local weight "rademacher"
local type   "wild"

********************************************************************************

eststo clear

/*Spec 1*/
	
/*Compute p-value for state clustered SE*/

	egen state_gadmid = group(state_gadm)
	egen district_gadmid = group(district_gadm)
	xtset state_gadmid district_gadmid
	
	local covs Land_250_1757 lnpdgpd1990
	local ncov : word count `covs'
	xtreg `lights' `covs', vce(robust) // Regression for state clustered SE
	matrix coefs = e(b) // Compute p-value for state clustered SE
	matrix varcov = e(V)
	local clusterb = coefs[1,1]
	local clusterSE = sqrt(varcov[1,1])
	local t = `clusterb'/`clusterSE'
	local clusterp = 2*(1 - normal(abs(`t')))

/*Compute p-value for Wild cluster bootstrap*/

eststo: xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, cluster(state_gadm)   	
		boottest Land_250_1757, seed(`seed') reps(`reps') weight(`weight') boottype(`type') // Wild bootstrap
		estadd scalar clusterp = `clusterp' 
		estadd scalar bootp = r(p) 	
		estadd beta
		matrix beta = e(beta)
		estadd scalar stb = beta[1,1]
		estimates store SE1
	
********************************************************************************

/*Spec 2*/

/*Make state FE*/

egen state_id = group(state_gadm)

levelsof state_id, local(state_id)
foreach i of local state_id {
		qui gen state_id_`i' = state_id == `i'
}
	
/*Compute p-value for state clustered SE*/

	xtset state_gadmid district_gadmid
	
	local covs Land_250_1757 lnpdgpd1990 state_id_* 
	local ncov : word count `covs'
	xtreg `lights' `covs', fe vce(robust) // Regression for state clustered SE
	matrix coefs = e(b) // Compute p-value for state clustered SE
	matrix varcov = e(V)
	local clusterb = coefs[1,1]
	local clusterSE = sqrt(varcov[1,1])
	local t = `clusterb'/`clusterSE'
	local clusterp = 2*(1 - normal(abs(`t')))

/*Compute p-value for Wild cluster bootstrap*/

eststo: xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm, cluster(state_gadm) 
		boottest Land_250_1757, seed(`seed') reps(`reps') weight(`weight') boottype(`type') // Wild bootstrap
		estadd scalar clusterp = `clusterp' 
		estadd scalar bootp = r(p) 	
		estadd beta
		matrix beta = e(beta)
		estadd scalar stb = beta[1,1]
		estimates store SE2

********************************************************************************

/*Spec 3*/
	
/*Compute p-value for state clustered SE*/

	xtset state_gadmid district_gadmid
	
	local covs Land_250_1757 lnpdgpd1990 state_id_* `controls_gis'
	local ncov : word count `covs'
	xtreg `lights' `covs', fe vce(robust) // Regression for state clustered SE
	matrix coefs = e(b) // Compute p-value for state clustered SE
	matrix varcov = e(V)
	local clusterb = coefs[1,1]
	local clusterSE = sqrt(varcov[1,1])
	local t = `clusterb'/`clusterSE'
	local clusterp = 2*(1 - normal(abs(`t')))

/*Compute p-value for Wild cluster bootstrap*/

eststo: xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', cluster(state_gadm) 	
		boottest Land_250_1757, seed(`seed') reps(`reps') weight(`weight') boottype(`type') // Wild bootstrap
		estadd scalar clusterp = `clusterp' 
		estadd scalar bootp = r(p) 	
		estadd beta
		matrix beta = e(beta)
		estadd scalar stb = beta[1,1]
		estimates store SE3

esttab SE1 SE2 SE3 using standarderror.tex, replace fragment ///
	keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(fmt(3))) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "clusterp State clustered p-value" "bootp Wild clustered bootstrap p-value" ///
		    "r2 \(R^{2}\)") sfmt(3 3 3 3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************

/*Compute Moran's I statistic*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

cap log close
log using footnotes_moransi, replace

moransi lnlights_001, lat(latitude_gadm ) lon(longitude_gadm ) swm(pow 1) dist(250) dunit(km) approx detail
moransi Land_250_1757, lat(latitude_gadm ) lon(longitude_gadm ) swm(pow 1) dist(250) dunit(km) approx detail

qui xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, r
	predict res1, residuals
	moransi res1, lat(latitude_gadm ) lon(longitude_gadm ) swm(pow 1) dist(250) dunit(km) approx detail

qui xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm, r beta
	predict res2, residuals
	moransi res2, lat(latitude_gadm ) lon(longitude_gadm ) swm(pow 1) dist(250) dunit(km) approx detail

qui xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	predict res3, residuals
	moransi res3, lat(latitude_gadm ) lon(longitude_gadm ) swm(pow 1) dist(250) dunit(km) approx detail

cap log close

/*
We have manually added the following below the "Wild clustered bootstrap p-value" line in Tex file:

Moran's I statistic & 0.508 & 0.070 & 0.044 \\
*/

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.11: Latitude and Longitude Polynomials*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

*Polynomials
gen latlonpoly1_y1=latitude_gadm
gen latlonpoly1_x1=longitude_gadm

gen latlonpoly2_y1=latitude_gadm
gen latlonpoly2_x1=longitude_gadm
gen latlonpoly2_y2=latitude_gadm^2
gen latlonpoly2_x2=longitude_gadm^2
gen latlonpoly2_xy=latitude_gadm*longitude_gadm

gen latlonpoly3_y1=latitude_gadm
gen latlonpoly3_x1=longitude_gadm
gen latlonpoly3_y2=latitude_gadm^2
gen latlonpoly3_x2=longitude_gadm^2
gen latlonpoly3_y3=latitude_gadm^3
gen latlonpoly3_x3=longitude_gadm^3
gen latlonpoly3_xy=latitude_gadm*longitude_gadm
gen latlonpoly3_x2y=(latitude_gadm^2)*longitude_gadm
gen latlonpoly3_xy2=latitude_gadm*(longitude_gadm^2)
gen latlonpoly3_x2y2=(latitude_gadm^2)*(longitude_gadm^2)

xi: reg lnlights_001 Land_250_1757 latlonpoly1_y1 latlonpoly1_x1 ///
    lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store latlonpoly1

xi: reg lnlights_001 Land_250_1757 latlonpoly1_y1 latlonpoly1_x1 ///
	latlonpoly2_y1 latlonpoly2_x1 latlonpoly2_y2 latlonpoly2_x2 latlonpoly2_xy ///
    lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store latlonpoly2

xi: reg lnlights_001 Land_250_1757 latlonpoly1_y1 latlonpoly1_x1 ///
	latlonpoly2_y1 latlonpoly2_x1 latlonpoly2_y2 latlonpoly2_x2 latlonpoly2_xy ///
	latlonpoly3_y1 latlonpoly3_x1 latlonpoly3_y2 latlonpoly3_x2 latlonpoly3_y3 ///
	latlonpoly3_x3 latlonpoly3_xy latlonpoly3_x2y latlonpoly3_xy2 latlonpoly3_x2y2 ///
    lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store latlonpoly3
	
esttab latlonpoly1 latlonpoly2 latlonpoly3 using latlonpoly.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

/*
We have manually added the following above the "Population density" line in Tex file:

\addlinespace
Order of polynomial (latitude and longitude) & 1 & 2 & 3 \\
*/

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.12: Conflict Types*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757 Siege_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store conflicttype1

xi: reg lnlights_001 Oneday_250_1757_ld Multiday_250_1757_ld lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store conflicttype2

xi: reg lnlights_001 Land_250_1757_int lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store conflicttype3

xi: reg lnlights_001 Conflict_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store conflicttype4

esttab conflicttype1 conflicttype2 conflicttype3 conflicttype4 using conflicttype.tex, ///
	replace fragment keep(Land_250_1757 Siege_250_1757 Oneday_250_1757_ld Multiday_250_1757_ld Land_250_1757_int Conflict_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-5}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure (benchmark)" Siege_250_1757 "Pre-colonial conflict exposure (sieges)" ///
	Oneday_250_1757_ld "Pre-colonial conflict exposure (single-day)" Multiday_250_1757_ld "Pre-colonial conflict exposure (multi-day)" ///
	Land_250_1757_int "Pre-colonial conflict exposure (India only)" Conflict_250_1757 "Pre-colonial conflict exposure (all)") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.13: 1500-1757 Conflict Sample*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1500_1757 lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store altstartdate1
	
xi: reg lnlights_001 Land_250_1500_1757 lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store altstartdate2

xi: reg lnlights_001 Land_250_1500_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store altstartdate3
	
esttab altstartdate1 altstartdate2 altstartdate3 using altstartdate.tex, ///
	replace fragment keep(Land_250_1500_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1500_1757 "Pre-colonial conflict exposure (1500-1757)") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.14: Alternative Conflict Data*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757_jc lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store altconflictdata1

xi: reg lnlights_001 Land_250_1757_jcn lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store altconflictdata2

esttab altconflictdata1 altconflictdata2 using altconflictdata.tex, ///
	replace fragment keep(Land_250_1757_jc Land_250_1757_jcn) ///
	b(3) se(3) posthead(\cmidrule(lr){2-3}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757_jc "Pre-colonial conflict exposure (plus Clodfelter)" ///
	Land_250_1757_jcn "Pre-colonial conflict exposure (plus Clodfelter and Narvane)") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.15: 5,000 km Radius*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_5000_1757 lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store cutoff1

xi: reg lnlights_001 Land_5000_1757 lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store cutoff2

xi: reg lnlights_001 Land_5000_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store cutoff3

esttab cutoff1 cutoff2 cutoff3 using altcutoff.tex, ///
	replace fragment keep(Land_5000_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_5000_1757 "Pre-colonial conflict exposure (5,000 km cutoff)") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.16: Running End-Date Cutoff*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_annex lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store altenddate1
	
xi: reg lnlights_001 Land_250_annex lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store altenddate2

xi: reg lnlights_001 Land_250_annex lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store altenddate3
	
esttab altenddate1 altenddate2 altenddate3 using altenddate.tex, ///
	replace fragment keep(Land_250_annex) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_annex "Pre-colonial conflict exposure (running end-date)") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	
	
********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.17: VIIRS Data*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

/*Make sample equivalent to benchmark sample*/

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, r beta
keep if e(sample)==1

xi: reg lnviirs_001 Land_250_1757 lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store viirs1
	
xi: reg lnviirs_001 Land_250_1757 lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store viirs2

xi: reg lnviirs_001 Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store viirs3
	
esttab viirs1 viirs2 viirs3 using viirs.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.18: GDP Outcome*/

cd "$output"
use "$cleandata\districtgdp.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lndgdppc_avg Land_250_1757 lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store gdppc_avg1
	
xi: reg lndgdppc_avg Land_250_1757 lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store gdppc_avg2

xi: reg lndgdppc_avg Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store gdppc_avg3
	
esttab gdppc_avg1 gdppc_avg2 gdppc_avg3 using altDVgdp.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.19: Initial State Capacity Controls*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757 plateII2a_neolithic lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate1

xi: reg lnlights_001 Land_250_1757 plateII2b_chalcolithic lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate2

xi: reg lnlights_001 Land_250_1757 plateIIID4_classical lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate3

xi: reg lnlights_001 Land_250_1757 plateIV4a_religious lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate4

xi: reg lnlights_001 Land_250_1757 lnipop1000 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate5

xi: reg lnlights_001 Land_250_1757 mp10_11_* lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate6

xi: reg lnlights_001 Land_250_1757 mp11_12_* lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate7
	
xi: reg lnlights_001 Land_250_1757 i1525_* lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate8

esttab initialstate1 initialstate2 initialstate3 initialstate4 initialstate5 initialstate6 initialstate7 initialstate8 using initialstate.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-9}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Neolithic settlements = plateII2a_neolithic" ///
	"Chalcolithic settlments = plateII2b_chalcolithic" ///
	"Cultural sites (300-700 CE) = plateIIID4_classical" /// 
	"Cultural sites (8th-12th centuries) = plateIV4a_religious" /// 
	"Ln(1+Urban population in 1000) = lnipop1000" ///
	"Major Indian states (10th-11th centuries) = mp10_11_*" ///
	"Major Indian states (11th-12th centuries) = mp11_12_*" ///
	"Major Indian states (in 1525) = i1525_*" ///
	"Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.20: Additional Geographic Features*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
local deposits "lndp_petroleum_s lndp_diamprim_s lndp_gem_s lndp_goldplacer_s"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 lnd_coast Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store addgeog1

xi: reg lnlights_001 river Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store addgeog2

xi: reg lnlights_001 irrpot Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store addgeog3
	
xi: reg lnlights_001 cvdelrain Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store addgeog4
	
xi: reg lnlights_001 `deposits' Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store addgeog5

xi: reg lnlights_001 pctforest Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store addgeog5

xi: reg lnlights_001 lnd_coast river irrpot cvdelrain `deposits' pctforest Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store addgeog6
		
esttab addgeog1 addgeog2 addgeog3 addgeog4 addgeog5 addgeog6 using additionalgeography.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-7}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Ln(1+Distance to coast) = lnd_coast" ///
	"River dummy = river" ///
	"Irrigation potential = irrpot" ///
	"Rainfall variation = cvdelrain" ///
	"Ln(1+Distance to resource deposit) = `deposits'" ///
	"\%Forest = pctforest" ///
	"Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls (benchmark) = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.21: Colonial Controls*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757 britdum lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial1

use "$cleandata\biclean.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"

xi: reg lnlights_001 Land_250_1757 p_nland lnpdgpd1990 i.state `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial2
	
esttab colonial1 colonial2 using colonial.tex, ///
	replace fragment keep(Land_250_1757 britdum p_nland) ///
	b(3) se(3) posthead(\cmidrule(lr){2-3}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure" britdum "Direct rule" ///
	p_nland "\%Non-landlord") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.22: Control for Colonial Railroad Network*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

*Rescale
replace rryear=rryear/1000
label var rryear "Year of Railroad/1000"

*Include districts with no colonial railroad
*Recode railroad year
gen norr=rryear==.
label var norr "No Railroad by 1934"
recode rryear (.=0)

xi: reg lnlights_001 Land_250_1757 rryear norr lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store controlrr1
	
xi: reg lnlights_001 Land_250_1757 rryear norr lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store controlrr2

xi: reg lnlights_001 Land_250_1757 rryear norr lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store controlrr3
	
esttab controlrr1 controlrr2 controlrr3 using controlrr.tex, ///
	replace fragment keep(Land_250_1757 rryear norr) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure" rryear "Year of Colonial RR/1000" norr "No Colonial RR by 1934") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.23: Exclude Canal Colonies*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

*Drop regions corresponding to historical Punjab
drop if state_gadm=="Punjab"
drop if state_gadm=="Himachal Pradesh"
drop if state_gadm=="Chandigarh"
drop if state_gadm=="NCT of Delhi"
drop if state_gadm=="Haryana"

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store nopunjab1

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store nopunjab2

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store nopunjab3
	
esttab nopunjab1 nopunjab2 nopunjab3 using nopunjab.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.24: Fractionalization Controls*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757 mport lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store frac1

xi: reg lnlights_001 Land_250_1757 yearsmuslim lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store frac2

xi: reg lnlights_001 Land_250_1757 sh_muslim lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store frac3

xi: reg lnlights_001 Land_250_1757 relpol lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store frac4
	
xi: reg lnlights_001 Land_250_1757 ethfrac lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store frac5

xi: reg lnlights_001 Land_250_1757 relfrac_census lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store frac6

xi: reg lnlights_001 Land_250_1757 cpctsc011 cpctst011 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store frac7

xi: reg lnlights_001 Land_250_1757 ganges lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store frac8
	
esttab frac1 frac2 frac3 frac4 frac5 frac6 frac7 frac8 using fractionalization.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-9}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Medieval port = mport" ///
	"Duration of Muslim rule = yearsmuslim" ///
	"Muslim share = sh_muslim" /// 
	"Religious polarization = relpol" ///
	"Linguistic fractionalization = ethfrac" ///
	"Religious fractionalization = relfrac_census" ///
	"Scheduled Caste share = cpctsc011" ///
	"Scheduled Tribe share = cpctst011" ///
	"Ganges River = ganges" ///
	"Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")		
	
********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.25: Post-1757 Conflict Controls*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757 Land_250_1758_1839 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store post1757conflict1

xi: reg lnlights_001 Land_250_1757 Land_250_1840_1946 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store post1757conflict2

xi: reg lnlights_001 Land_250_1757 Land_250_1947 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store post1757conflict3

xi: reg lnlights_001 Land_250_1757 Land_250_1758_1839 Land_250_1840_1946 Land_250_1947 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store post1757conflict4

esttab post1757conflict1 post1757conflict2 post1757conflict3 post1757conflict4 using post1757conflict.tex, ///
	replace fragment keep(Land_250_1757 Land_250_1758_1839 Land_250_1840_1946 Land_250_1947) ///
	b(3) se(3) posthead(\cmidrule(lr){2-5}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure" Land_250_1758_1839 "Colonial conflict exposure (1758-1839)" ///
	Land_250_1840_1946 "Colonial conflict exposure (1840-1946)" Land_250_1947 "Post-colonial conflict exposure (1947-2010)") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.26: Controls for Urban Distances*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757 d5_bang d5_mumbai d5_chen d5_delhi d5_kolk lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store fivecities1
	
xi: reg lnlights_001 Land_250_1757 d5_bang d5_mumbai d5_chen d5_delhi d5_kolk lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store fivecities2

xi: reg lnlights_001 Land_250_1757 d5_bang d5_mumbai d5_chen d5_delhi d5_kolk lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store fivecities3

esttab fivecities1 fivecities2 fivecities3 using fivecities.tex, ///
	replace fragment keep(Land_250_1757 d5_bang d5_mumbai d5_chen d5_delhi d5_kolk) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure" ///
	d5_bang "Distance from Bangalore" ///
	d5_mumbai "Distance from Bombay" ///
	d5_chen "Distance from Chennai" ///
	d5_delhi "Distance from Delhi" ///
	d5_kolk "Distance from Kolkata") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.27: Asian Highway Control*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757 ah1 lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store ah11
	
xi: reg lnlights_001 Land_250_1757 ah1 lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store ah12

xi: reg lnlights_001 Land_250_1757 ah1 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store ah13

esttab ah11 ah12 ah13 using ah1.tex, ///
	replace fragment keep(Land_250_1757 ah1) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure" ///
	ah1 "Asian Highway") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.28: Pairwise Correlations: Alternative Exposure Measures*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

reg lnlights_001 Land_250_1757 lnpdgpd1990
keep if e(sample)

estpost corr Land_250_1757 conflictsbycapital Land_250_1757_capital conflictsbyactor chull_title, matrix listwise
eststo correlation
esttab correlation using pwcorr_conflictvars.csv, unstack compress b(3) replace label

/*We have manually made the Tex table here*/

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.29: Alternative Conflict Exposure Measures*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"
 
xi: reg lnlights_001 conflictsbycapital lnpdgpd1990 i.state_gadm `controls_gis', r beta	
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store altconflictmeasure1

xi: reg lnlights_001 Land_250_1757_capital lnpdgpd1990 i.state_gadm `controls_gis', r beta	
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store altconflictmeasure2

xi: reg lnlights_001 conflictsbyactor lnpdgpd1990 i.state_gadm `controls_gis', r beta	
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store altconflictmeasure3
		
xi: reg lnlights_001 chull_title lnpdgpd1990 i.state_gadm `controls_gis', r beta	
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store altconflictmeasure4

esttab altconflictmeasure1 altconflictmeasure2 altconflictmeasure3 altconflictmeasure4 using altconflictmeasure.tex, ///
	replace fragment keep(conflictsbycapital conflictsbyactor Land_250_1757_capital chull_title) ///
	b(3) se(3) posthead(\cmidrule(lr){2-5}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(conflictsbyactor "Pre-colonial conflict exposure \\ (\# conflicts in convex hull, by participant)" ///
	chull_title "Pre-colonial conflict exposure \\ (\# conflicts in convex hull, by conflict group)" ///
	Land_250_1757_capital "Pre-colonial conflict exposure \\ (Benchmark measure, by location of participant capitals)" ///
	conflictsbycapital "Pre-colonial conflict exposure \\ (\# conflicts in district of state capital)") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.30: IV: Reduced Form*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 instrument lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store ivreduced1
	
xi: reg lnlights_001 instrument lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store ivreduced2

xi: reg lnlights_001 instrument lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store ivreduced3
	
esttab ivreduced1 ivreduced2 ivreduced3 using ivreducedform.tex, ///
	replace fragment keep(instrument) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(instrument "Proximity to Khyber Pass") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.31: IV: Balance Tests: Historical Trade*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"


xi: reg tr17c instrument lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estimates store ivtradebalance1
	
xi: reg unescosilkroad instrument lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estimates store ivtradebalance2
	
xi: reg mport instrument lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estimates store ivtradebalance3

esttab ivtradebalance1 ivtradebalance2 ivtradebalance3 using ivtradebalance.tex, ///
	replace fragment keep(instrument) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(instrument "Cost distance to Kyhber Pass") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.32: IV: Exclude Districts with Historical Trade*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"
			
/*First stage*/

xi: reg Land_250_1757 instrument lnpdgpd1990 i.state_gadm `controls_gis' if tr17c~=1, r beta
	estadd ysumm
	estimates store noivtrade_firststage1

xi: reg Land_250_1757 instrument lnpdgpd1990 i.state_gadm `controls_gis' if unescosilkroad~=1, r beta
	estadd ysumm
	estimates store noivtrade_firststage2

xi: reg Land_250_1757 instrument lnpdgpd1990 i.state_gadm `controls_gis' if mport~=1, r beta
	estadd ysumm
	estimates store noivtrade_firststage3

/*
We have manually added the following above the "Population density" line in Tex file:

\addlinespace
Exclude districts  & Historical trade route & Silk Road site  & Medieval port \\
*/

esttab noivtrade_firststage1 noivtrade_firststage2 noivtrade_firststage3 using noivtrade_firststage.tex, ///
	replace fragment keep(instrument) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(instrument "Cost distance to Kyhber Pass") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

/*Second stage*/

xi: ivreg2 lnlights_001 (Land_250_1757=instrument) lnpdgpd1990 i.state_gadm `controls_gis' if tr17c~=1, r ffirst
	estadd ysumm
	estimates store noivtrade_secondstage1

xi: ivreg2 lnlights_001 (Land_250_1757=instrument) lnpdgpd1990 i.state_gadm `controls_gis' if unescosilkroad~=1, r ffirst
	estadd ysumm
	estimates store noivtrade_secondstage2

xi: ivreg2 lnlights_001 (Land_250_1757=instrument) lnpdgpd1990 i.state_gadm `controls_gis' if mport~=1, r ffirst
	estadd ysumm
	estimates store noivtrade_secondstage3

/*
We have manually added the following above the "Population density" line in Tex file:

\addlinespace
Exclude districts & Historical trade route & Silk Road site & Medieval port \\
*/

esttab noivtrade_secondstage1 noivtrade_secondstage2 noivtrade_secondstage3 using noivtrade_secondstage.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("archi2p Anderson-Rubin p-value" "widstat Kleibergen-Paap Wald rk F-statistic") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.33: IV: Historical Trade Controls*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"
		
/*First stage*/

xi: reg Land_250_1757 instrument lnpdgpd1990 i.state_gadm `controls_gis' tr17c, r beta
	estadd ysumm
	estimates store ivtrade_firststage1

xi: reg Land_250_1757 instrument lnpdgpd1990 i.state_gadm `controls_gis' unescosilkroad, r beta
	estadd ysumm
	estimates store ivtrade_firststage2

xi: reg Land_250_1757 instrument lnpdgpd1990 i.state_gadm `controls_gis' mport, r beta
	estadd ysumm
	estimates store ivtrade_firststage3

esttab ivtrade_firststage1 ivtrade_firststage2 ivtrade_firststage3 using ivtrade_firststage.tex, ///
	replace fragment keep(instrument) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(instrument "Cost distance to Kyhber Pass") ///
	indicate("Historical trade route = tr17c" "Silk Road site = unescosilkroad" "Medieval trade port = mport" ///
	"Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

/*Second stage*/

xi: ivreg2 lnlights_001 (Land_250_1757=instrument) lnpdgpd1990 i.state_gadm `controls_gis' tr17c, r ffirst
	estadd ysumm
	estimates store ivtrade_secondstage1

xi: ivreg2 lnlights_001 (Land_250_1757=instrument) lnpdgpd1990 i.state_gadm `controls_gis' unescosilkroad, r ffirst
	estadd ysumm
	estimates store ivtrade_secondstage2

xi: ivreg2 lnlights_001 (Land_250_1757=instrument) lnpdgpd1990 i.state_gadm `controls_gis' mport, r ffirst
	estadd ysumm
	estimates store ivtrade_secondstage3

esttab ivtrade_secondstage1 ivtrade_secondstage2 ivtrade_secondstage3 using ivtrade_secondstage.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("archi2p Anderson-Rubin p-value" "widstat Kleibergen-Paap Wald rk F-statistic") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Historical trade route = tr17c" "Silk Road site = unescosilkroad" "Medieval trade port = mport" ///
	"Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.34: IV: Historical Trade Controls (Cost Distance)*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"
		
/*First stage*/

xi: reg Land_250_1757 instrument lnpdgpd1990 i.state_gadm `controls_gis' tradertrsq, r beta
	estadd ysumm
	estimates store ivtradeCD_firststage1

xi: reg Land_250_1757 instrument lnpdgpd1990 i.state_gadm `controls_gis' silkrdrsq, r beta
	estadd ysumm
	estimates store ivtradeCD_firststage2

xi: reg Land_250_1757 instrument lnpdgpd1990 i.state_gadm `controls_gis' jhaportrsq, r beta
	estadd ysumm
	estimates store ivtradeCD_firststage3

esttab ivtradeCD_firststage1 ivtradeCD_firststage2 ivtradeCD_firststage3 using ivtradeCD_firststage.tex, ///
	replace fragment keep(instrument) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(instrument "Cost distance to Kyhber Pass") ///
	indicate("Historical trade route (cost distance)= tradertrsq" "Silk Road site (cost distance) = silkrdrsq" "Medieval trade port (cost distance) = jhaportrsq" ///
	"Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

/*Second stage*/

xi: ivreg2 lnlights_001 (Land_250_1757=instrument) lnpdgpd1990 i.state_gadm `controls_gis' tradertrsq, r ffirst
	estadd ysumm
	estimates store ivtradeCD_secondstage1

xi: ivreg2 lnlights_001 (Land_250_1757=instrument) lnpdgpd1990 i.state_gadm `controls_gis' silkrdrsq, r ffirst
	estadd ysumm
	estimates store ivtradeCD_secondstage2

xi: ivreg2 lnlights_001 (Land_250_1757=instrument) lnpdgpd1990 i.state_gadm `controls_gis' jhaportrsq, r ffirst
	estadd ysumm
	estimates store ivtradeCD_secondstage3

esttab ivtradeCD_secondstage1 ivtradeCD_secondstage2 ivtradeCD_secondstage3 using ivtradeCD_secondstage.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("archi2p Anderson-Rubin p-value" "widstat Kleibergen-Paap Wald rk F-statistic") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Historical trade route (cost distance)= tradertrsq" "Silk Road site (cost distance) = silkrdrsq" "Medieval trade port (cost distance) = jhaportrsq" ///
	"Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.35: IV: Placebo Entry Points*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"
	
foreach var of varlist suratrsq kodungrsq goarsq calicutrsq bombayrsq {
	preserve
		gen tempinstrument=instrument_`var'
		label var tempinstrument "Placebo Instrument"
		/*First stage*/
		xi: reg Land_250_1757 tempinstrument lnpdgpd1990 i.state_gadm `controls_gis', r beta
		estadd ysumm
		estimates store ivp_fs_`var'
		/*Second stage*/
		xi: ivreg2 lnlights_001 (Land_250_1757=tempinstrument) lnpdgpd1990 i.state_gadm `controls_gis', r ffirst
		estadd ysumm
		estimates store ivp_ss_`var'
	restore
}

/*
We have manually added the following above the "Population density" line in Tex file:

\addlinespace
Placebo entry point  & Surat &  Kodungallur & Goa & Calicut & Bombay \\
*/

esttab ivp_fs_suratrsq ivp_fs_kodungrsq ivp_fs_goarsq ivp_fs_calicutrsq ivp_fs_bombayrsq using ivplacebo_firststage.tex, ///
	replace fragment keep(tempinstrument) ///
	b(3) se(3) posthead(\cmidrule(lr){2-6}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(tempinstrument "Cost distance to placebo entry point") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

/*
We have manually added the following above the "Population density" line in Tex file:

\addlinespace
Placebo entry point  & Surat &  Kodungallur & Goa & Calicut & Bombay \\
*/

esttab ivp_ss_suratrsq ivp_ss_kodungrsq ivp_ss_goarsq ivp_ss_calicutrsq ivp_ss_bombayrsq using ivplacebo_secondstage.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-6}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("archi2p Anderson-Rubin p-value" "widstat Kleibergen-Paap Wald rk F-statistic") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.36: IV: Alternative Cost-Distance*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"
	
/*Loop over alt cost-distance vars 1-3, with cutoff<=50*/

foreach dvar in cd1 cd2 cd3 {
	preserve
		gen tempinstrument=instrument_`dvar'
		label var tempinstrument "Alternative Instrument"
		/*First stage*/
		xi: reg Land_250_1757 tempinstrument lnpdgpd1990 i.state_gadm `controls_gis', r beta
		estadd ysumm
		estimates store ivalt_fs_`dvar'
		/*Second stage*/
		xi: ivreg2 lnlights_001 (Land_250_1757=tempinstrument) lnpdgpd1990 i.state_gadm `controls_gis', r ffirst
		estadd ysumm
		estimates store ivalt_ss_`dvar'
	restore
}	

/*Loop over alt cost-distance var 4 (i.e. HMI), with cutoff<=100*/

foreach dvar in cd4 {
	preserve
		gen tempinstrument=instrument_`dvar'
		label var tempinstrument "Alternative Instrument"
		/*First stage*/
		xi: reg Land_250_1757 tempinstrument lnpdgpd1990 i.state_gadm `controls_gis', r beta
		estadd ysumm
		estimates store ivalt_fs_`dvar'
		/*Second stage*/
		xi: ivreg2 lnlights_001 (Land_250_1757=tempinstrument) lnpdgpd1990 i.state_gadm `controls_gis', r ffirst
		estadd ysumm
		estimates store ivalt_ss_`dvar'
	restore
}	

/*
We have manually added the following above the "Population density" line in Tex file:

\addlinespace
Alternative cost distance  & Linear slope & Squared slope & Linear ruggedness & HMI \\
*/	
	
esttab ivalt_fs_cd1 ivalt_fs_cd2 ivalt_fs_cd3 ivalt_fs_cd4 using ivalt_firststage.tex, ///
	replace fragment keep(tempinstrument) ///
	b(3) se(3) posthead(\cmidrule(lr){2-5}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(tempinstrument "Cost distance to Khyber Pass (alternative)") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

/*
We have manually added the following above the "Population density" line in Tex file:

\addlinespace
Alternative cost distance  & Linear slope & Squared slope & Linear ruggedness & HMI \\
*/	

esttab ivalt_ss_cd1 ivalt_ss_cd2 ivalt_ss_cd3 ivalt_ss_cd4 using ivalt_secondstage.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-5}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("archi2p Anderson-Rubin p-value" "widstat Kleibergen-Paap Wald rk F-statistic") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.37: OLS: Include Pakistan and Bangladesh*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear
append using "$cleandata\bgdpak.dta"

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store addbgdpak1
	
xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store addbgdpak2

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store addbgdpak3
	
esttab addbgdpak1 addbgdpak2 addbgdpak3 using addbgdpak.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.38: IV: Include Pakistan and Bangladesh*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear
append using "$cleandata\bgdpak.dta"

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

*IV: Cutoff of 50
*Instrument must be redefined
xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, r beta
egen costrank=rank(khyberrsq) if e(sample), track
	gen instrument50=costrank<=50 if e(sample)
	label var instrument50 "Khyber Proximity"
	drop costrank

/*First stage*/

xi: reg Land_250_1757 instrument50 lnpdgpd1990, r beta
	estadd ysumm
	estimates store addbgdpak_iv50_firststage1

xi: reg Land_250_1757 instrument50 lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estimates store addbgdpak_iv50_firststage2

xi: reg Land_250_1757 instrument50 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estimates store addbgdpak_iv50_firststage3
	
esttab addbgdpak_iv50_firststage1 addbgdpak_iv50_firststage2 addbgdpak_iv50_firststage3 using addbgdpak_iv50_firststage.tex, ///
	replace fragment keep(instrument50) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(instrument50 "Cost distance to Kyhber Pass") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

/*Second stage*/

xi: ivreg2 lnlights_001 (Land_250_1757=instrument50) lnpdgpd1990, r ffirst
	estadd ysumm
	estimates store addbgdpak_iv50_secondstage1
	
xi: ivreg2 lnlights_001 (Land_250_1757=instrument50) lnpdgpd1990 i.state_gadm, r ffirst
	estadd ysumm
	estimates store addbgdpak_iv50_secondstage2

xi: ivreg2 lnlights_001 (Land_250_1757=instrument50) lnpdgpd1990 i.state_gadm `controls_gis', r ffirst
	estadd ysumm
	estimates store addbgdpak_iv50_secondstage3

esttab addbgdpak_iv50_secondstage1 addbgdpak_iv50_secondstage2 addbgdpak_iv50_secondstage3 using addbgdpak_iv50_secondstage.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("archi2p Anderson-Rubin p-value" "widstat Kleibergen-Paap Wald rk F-statistic") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	
	
********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.39: IV: Control for Colonial Railroad Network*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"
		
*Rescale
replace rryear=rryear/1000
label var rryear "Year of Railroad/1000"

*Include districts with no colonial railroad
*Recode railroad year
gen norr=rryear==.
label var norr "No Railroad by 1934"
recode rryear (.=0)

/*First stage*/

xi: reg Land_250_1757 instrument rryear norr lnpdgpd1990, r beta
	estadd ysumm
	estimates store iv_controlrr1

xi: reg Land_250_1757 instrument rryear norr lnpdgpd1990 i.state_gadm, r beta
	estadd ysumm
	estimates store iv_controlrr2

xi: reg Land_250_1757 instrument rryear norr lnpdgpd1990 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estimates store iv_controlrr3
	
esttab iv_controlrr1 iv_controlrr2 iv_controlrr3 using iv_controlrr_firststage.tex, ///
	replace fragment keep(instrument rryear norr) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(instrument "Proximity to Khyber Pass" rryear "Year of Colonial RR" norr "No Colonial RR by 1934") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")	

/*Second stage*/

xi: ivreg2 lnlights_001 (Land_250_1757=instrument) rryear norr lnpdgpd1990, r ffirst
	estadd ysumm
	estimates store iv_controlrr1
	
xi: ivreg2 lnlights_001 (Land_250_1757=instrument) rryear norr lnpdgpd1990 i.state_gadm, r ffirst
	estadd ysumm
	estimates store iv_controlrr2

xi: ivreg2 lnlights_001 (Land_250_1757=instrument) rryear norr lnpdgpd1990 i.state_gadm `controls_gis', r ffirst
	estadd ysumm
	estimates store iv_controlrr3

esttab iv_controlrr1 iv_controlrr2 iv_controlrr3 using iv_controlrr_secondstage.tex, ///
	replace fragment keep(Land_250_1757 rryear norr) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("archi2p Anderson-Rubin p-value" "widstat Kleibergen-Paap Wald rk F-statistic") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure" rryear "Year of Colonial RR/1000" norr "No Colonial RR by 1934") ///
	indicate("Population density = lnpdgpd1990" "State FE = *state*" "Geographic controls = `controls_gis'")
	
********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.40: Pre-Colonial-Era State-Making: Control for Sieges*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

/*Make sample equivalent to benchmark sample*/
xi: reg lnlights_001 Land_250_1526 lnpdgpd1990, r beta
	keep if e(sample)
	
xi: reg plateVIA4_any Land_250_1757 Siege_250_1757 `controls_gis' i.state_gadm lnhyde1500, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate31

xi: reg babur Land_250_1526 Siege_250_1526 `controls_gis' i.state_gadm lnhyde1500, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate32

xi: reg akbar Land_250_1556 Siege_250_1556 `controls_gis' i.state_gadm lnhyde1500, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate33

xi: reg aurangzeb Land_250_1658 Siege_250_1658 `controls_gis' i.state_gadm lnhyde1500, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store initialstate34
	
esttab initialstate31 initialstate32 initialstate33 initialstate34 using initialstate3.tex, ///
	replace fragment keep(Land_250_1757 Land_250_1526 Land_250_1556 Land_250_1658 Siege_250_1757 Siege_250_1526 Siege_250_1556 Siege_250_1658) ///
	b(3) se(3) posthead(\cmidrule(lr){2-5}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure (benchmark)" ///
	Land_250_1526 "Pre-colonial conflict exposure (benchmark)" ///
	Land_250_1556 "Pre-colonial conflict exposure (benchmark)" ///
	Land_250_1658 "Pre-colonial conflict exposure (benchmark)" ///
	Siege_250_1757 "Pre-colonial conflict exposure (sieges)" ///
	Siege_250_1526 "Pre-colonial conflict exposure (sieges)" ///
	Siege_250_1556 "Pre-colonial conflict exposure (sieges)" ///
	Siege_250_1658 "Pre-colonial conflict exposure (sieges)") ///
	indicate("Population density = lnhyde1500" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.41: Colonial Fiscal Development: Control for Pre-Colonial State-Making*/

cd "$output"
use "$cleandata\conflictexposure_native.dta", clear

local controls_gis "latitude longitude altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg lnlandrevpa Land_250_1757 plateVIA4_any `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial31

xi: reg lnlandrevpc Land_250_1757 plateVIA4_any `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial32

xi: reg lnlandrevpa Land_250_1757 babur `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial33

xi: reg lnlandrevpc Land_250_1757 babur `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial34

xi: reg lnlandrevpa Land_250_1757 akbar `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial35

xi: reg lnlandrevpc Land_250_1757 akbar `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial36

xi: reg lnlandrevpa Land_250_1757 aurangzeb `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial37

xi: reg lnlandrevpc Land_250_1757 aurangzeb `controls_gis' i.state_gadm lnhyde1850, r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonial38

esttab colonial31 colonial32 colonial33 colonial34 colonial35 colonial36 colonial37 colonial38 using colonial3.tex, ///
	replace fragment keep(Land_250_1757 babur akbar aurangzeb plateVIA4_any) ///
	b(3) se(3) posthead(\cmidrule(lr){2-9}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure" babur "Babur" akbar "Akbar" auranggzeb "Auranggzeb" plateVIA4_any "Important Mughal sites") ///
	indicate("Population density = _cons" "State FE = *state*" "Geographic controls = `controls_gis'")		
	
********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.42: Colonial and Post-Colonial Conflict: Sub-District as Unit of Analysis*/

cd "$output"
use "$cleandata\tehsildata.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"
egen districtid=group(state_gadm district_gadm)

xi: reg Land_250_1758_1839 Land_250_1757 lnhyde1750 i.state_gadm `controls_gis' if lnlights_001!=., cl(districtid)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict31

xi: reg Conflict_250_1758_1839 Land_250_1757 lnhyde1750 i.state_gadm `controls_gis' if lnlights_001!=., cl(districtid)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict32

xi: reg Land_250_1840_1946 Land_250_1757 lnhyde1850 i.state_gadm `controls_gis' if lnlights_001!=., cl(districtid)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict33

xi: reg Conflict_250_1840_1946 Land_250_1757 lnhyde1850 i.state_gadm `controls_gis' if lnlights_001!=., cl(districtid)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict34

xi: reg Land_250_1947 Land_250_1757 lnhyde1950 i.state_gadm `controls_gis' if lnlights_001!=., cl(districtid)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store postcolonialconflict31

xi: reg Conflict_250_1947 Land_250_1757 lnhyde1950 i.state_gadm `controls_gis' if lnlights_001!=., cl(districtid)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store postcolonialconflict32
	
cd "$output"
use "$cleandata\tehsildata.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"
egen districtid=group(state_gadm district_gadm)

xi: reg fatalities2 Land_250_1757 i.state_gadm lnpdgpd1990 `controls_gis', cl(districtid)
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store acled21

esttab colonialconflict31 colonialconflict32 colonialconflict33 colonialconflict34 ///
	postcolonialconflict31 postcolonialconflict32 acled21 using colonialpostcolonialconflict3.tex, ///
	replace fragment keep(Land_250_1757) ///
	b(3) se(3) posthead(\cmidrule(lr){2-8}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure" Land_250_1758_1839) ///
	indicate("Population density = _cons" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.43: Colonial and Post-Colonial Conflict: Control for Pre-Colonial State-Making*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

xi: reg Land_250_1758_1839 Land_250_1757 plateVIA4_any lnhyde1750 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict21

xi: reg Land_250_1758_1839 Land_250_1757 babur lnhyde1750 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict22

xi: reg Land_250_1758_1839 Land_250_1757 akbar lnhyde1750 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict23

xi: reg Land_250_1758_1839 Land_250_1757 aurangzeb lnhyde1750 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict24

xi: reg Land_250_1840_1946 Land_250_1757 plateVIA4_any lnhyde1850 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict25

xi: reg Land_250_1840_1946 Land_250_1757 babur lnhyde1850 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict26

xi: reg Land_250_1840_1946 Land_250_1757 akbar lnhyde1850 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict27

xi: reg Land_250_1840_1946 Land_250_1757 aurangzeb lnhyde1850 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store colonialconflict28 

xi: reg Land_250_1947 Land_250_1757 plateVIA4_any lnhyde1950 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store postcolonialconflict29

xi: reg Land_250_1947 Land_250_1757 babur lnhyde1950 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store postcolonialconflict210

xi: reg Land_250_1947 Land_250_1757 akbar lnhyde1950 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store postcolonialconflict211
	
xi: reg Land_250_1947 Land_250_1757 aurangzeb lnhyde1950 i.state_gadm `controls_gis' if lnlights_001!=., r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store postcolonialconflict212
	
esttab colonialconflict21 colonialconflict22 colonialconflict23 colonialconflict24 colonialconflict25 colonialconflict26 colonialconflict27 colonialconflict28 ///
	postcolonialconflict29 postcolonialconflict210 postcolonialconflict211 postcolonialconflict212 using colonialpostcolonialconflict2.tex, ///
	replace fragment keep(Land_250_1757 babur akbar aurangzeb plateVIA4_any) ///
	b(3) se(3) posthead(\cmidrule(lr){2-13}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure" babur "Babur" akbar "Akbar" auranggzeb "Auranggzeb" plateVIA4_any "Important Mughal sites") ///
	indicate("Population density = _cons" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************

/*TABLE A.44: Do Historical Investments Persist?*/

cd "$output"
use "$cleandata\exposure_bi.dta", clear

rename Land_250_1757_collapsed Land_250_1757

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"

xi: reg irr_g_avg2 Land_250_1757 prop_canal_312 lnhyde1950 i.state `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store persist1

cd "$output"
use "$cleandata\exposure_bi_literacy.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"

rename Land_250_1757_collapsed Land_250_1757

xi: reg lrate_avg2 Land_250_1757 literacy21 lnhyde1950 i.state `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store persist2
	
cd "$output"
use "$cleandata\devcensuswgis.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if areaname=="Nicobars" | areaname=="South Andaman" | areaname=="North  & Middle Andaman" | areaname=="Lakshadweep"
gen lnpopd2001=ln(dinfo136_2001)

rename Land_250_1757_collapsed Land_250_1757
	
xi: reg cinfo324_2011 Land_250_1757 literacy21 lnpopd2011 i.state_gadm `controls_gis', r beta
	estadd ysumm
	estadd beta
	matrix beta = e(beta)
	estadd scalar stb = beta[1,1]
	estimates store persist3
	
esttab persist1 persist2 persist3 using persist.tex, ///
	replace fragment keep(Land_250_1757 prop_canal_312 literacy21) ///
	b(3) se(3) posthead(\cmidrule(lr){2-4}) ///
	cells(b(star fmt(3)) se(fmt(3) par) p(fmt(3) par([ ]))) staraux star(* 0.10 ** 0.05 *** 0.01) collabels(none) ///
	label booktabs noconstant obslast nodepvars nomtitles nolines gaps ///
	scalars("stb Standardized beta coefficient" "r2 \(R^{2}\)") sfmt(3) ///
	coeflabel(Land_250_1757 "Pre-colonial conflict exposure" prop_canal_312 "\%Irrigated in 1931" literacy21 "\%Literacy in 1921") ///
	indicate("Population density = _cons" "State FE = *state*" "Geographic controls = `controls_gis'")	

********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************

/*FIGURES IN APPENDIX*/

********************************************************************************
********************************************************************************
********************************************************************************

/*Figure A.1: Conflict Locations, 1000-2010*/

/*Map made in ArcGIS*/

********************************************************************************
********************************************************************************
********************************************************************************

/*Figure A.2: Conflict Locations by Sub-Period*/

/*Map made in ArcGIS*/

********************************************************************************
********************************************************************************
********************************************************************************

/*Figure A.3: Artificial Spatially-Correlated Noise Placebo Variables*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear
cd "$output"

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"
set seed 72826 

*Set up results file
gen iter=0
forvalues i=1/3 {
	gen b`i'=.
}

*Baseline values
qui xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, r beta
	gen b01=_b[Land_250_1757]
qui xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm, r beta
	gen b02=_b[Land_250_1757]
qui xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
	gen b03=_b[Land_250_1757]
qui moransi Land_250_1757, lat(latitude_gadm ) lon(longitude_gadm ) swm(pow 1) dist(250) dunit(km) approx detail
	gen mI0=r(I)
keep if _n==1
keep iter b1 b2 b3 mI0 b01 b02 b03
saveold rimanual, replace 

*Simulations
forvalues i=1/999 {
	di "`i'"

*Load data
	qui use "$cleandata\conflictexposure.dta", clear
	qui local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
	qui drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

*Randomly reallocate treatment, but keep it within states
	qui bysort state_gadm : gen rowno=_n
	qui preserve
		qui keep state_gadm Land_250_1757
		qui rename Land_250_1757 riLand_250_1757
		qui gen rand=rnormal()
		bysort state_gadm : egen rowno=rank(rand)
		qui drop rand
		qui sort state_gadm rowno
		qui saveold jamestemp, replace
	qui restore
	qui sort state_gadm rowno
	qui merge state_gadm rowno using jamestemp
	qui gen iter=`i'
		
*Save Moran's I
	qui moransi riLand_250_1757, lat(latitude_gadm) lon(longitude_gadm) swm(pow 1) dist(250) dunit(km) approx detail
	qui gen mI=r(I)
	
*Column 1
	qui xi: reg lnlights_001 riLand_250_1757 lnpdgpd1990, r beta
		qui gen b1=_b[riLand_250_1757]
		
*Column 2
	qui xi: reg lnlights_001 riLand_250_1757 lnpdgpd1990 i.state_gadm, r beta
		qui gen b2=_b[riLand_250_1757]
	
*Column 3
	qui xi: reg lnlights_001 riLand_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
		qui gen b3=_b[riLand_250_1757]
		
*Append to results file
	qui keep if _n==1
	qui keep iter mI b1 b2 b3 
	qui append using rimanual 
	qui saveold rimanual, replace
}
erase jamestemp.dta

*Label variables created
label var iter "Iterations"
label var mI "Moran's I"
label var b1 "Beta: Column 1"
label var b2 "Beta: Column 2"
label var b3 "Beta: Column 3"
label var mI0 "Initial Moran's I"
label var b01 "Initial Beta: Column 1"
label var b02 "Initial Beta: Column 2"
label var b03 "Initial Beta: Column 3"
foreach var of varlist mI0 b01 b02 b03 {
	egen junk=mean(`var')
	replace `var'=junk
	drop junk
}
egen avgmI=mean(mI)
drop if iter==0
sort iter
saveold rimanual, replace 

*Pictures
use rimanual, clear

*Round reported numbers for appearance
foreach var in avgmI b01 b02 b03 {
	tostring `var', replace force
	replace `var'=substr(`var',1,5)
}

local Mavg=avgmI[1]
local b0=b01[1]
twoway (kdensity b1, xline(`b0')), scheme(lean1) legend(off) ///
	title("") xtitle("") ytitle("Density") ///
	note("Average Moran's I: `Mavg'") ///
	caption("Baseline coefficient estimate: `b0'") 
graph export ric1.png, as(png) width(2500) replace
local b0=b02[1]
twoway (kdensity b2, xline(`b0')), scheme(lean1) legend(off) ///
	title("") xtitle("") ytitle("Density") ///
	note("Average Moran's I: `Mavg'") ///
	caption("Baseline coefficient estimate: `b0'") 
graph export ric2.png, as(png) width(2500) replace
local b0=b03[1]
twoway (kdensity b3, xline(`b0')), scheme(lean1) legend(off) ///
	title("") xtitle("") ytitle("Density") ///
	note("Average Moran's I: `Mavg'") ///
	caption("Baseline coefficient estimate: `b0'") 
graph export ric3.png, as(png) width(2500) replace

********************************************************************************
********************************************************************************
********************************************************************************

/*Figure A.4: Exclude States One by One*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

gen id=0
replace id=1 if state_gadm=="Andaman and Nicobar" 
replace id=2 if state_gadm=="Andhra Pradesh" 
replace id=3 if state_gadm=="Arunachal Pradesh" 
replace id=4 if state_gadm=="Assam" 
replace id=5 if state_gadm=="Bihar" 
replace id=6 if state_gadm=="Chandigarh" 
replace id=7 if state_gadm=="Chhattisgarh" 
replace id=8 if state_gadm=="Dadra and Nagar Haveli" 
replace id=9 if state_gadm=="Daman and Diu" 
replace id=10 if state_gadm=="Goa" 
replace id=11 if state_gadm=="Gujarat" 
replace id=12 if state_gadm=="Haryana" 
replace id=13 if state_gadm=="Himachal Pradesh" 
replace id=14 if state_gadm=="Jammu and Kashmir" 
replace id=15 if state_gadm=="Jharkhand" 
replace id=16 if state_gadm=="Karnataka" 
replace id=17 if state_gadm=="Kerala" 
replace id=18 if state_gadm=="Lakshadweep" 
replace id=19 if state_gadm=="Madhya Pradesh" 
replace id=20 if state_gadm=="Maharashtra"  
replace id=21 if state_gadm=="Manipur" 
replace id=22 if state_gadm=="Meghalaya" 
replace id=23 if state_gadm=="Mizoram" 
replace id=24 if state_gadm=="NCT of Delhi" 
replace id=25 if state_gadm=="Nagaland" 
replace id=26 if state_gadm=="Odisha" 
replace id=27 if state_gadm=="Puducherry" 
replace id=28 if state_gadm=="Punjab" 
replace id=29 if state_gadm=="Rajasthan" 
replace id=30 if state_gadm=="Sikkim"  
replace id=31 if state_gadm=="Tamil Nadu" 
replace id=32 if state_gadm=="Telangana"
replace id=33 if state_gadm=="Tripura"
replace id=34 if state_gadm=="Uttar Pradesh"
replace id=35 if state_gadm=="Uttarakhand"
replace id=36 if state_gadm=="West Bengal"

order id

cd "$output"

local statelocal "1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36"
local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

foreach p of local statelocal {
	qui xi: reg lnlights_001 Land_250_1757 `controls_gis' i.state_gadm lnpdgpd1990 if id!=`p', r 
	parmest, le(95) sa("nostate_`p'.dta", replace)
}

foreach p of local statelocal {
	use "nostate_`p'.dta", clear
	gen N=_n
	keep if N==1
	gen dropstate="`p'"
	keep parm estimate min95 max95 dropstate
	save, replace
}

local statelocal "1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36"
use "nostate_1.dta", clear
foreach p of local statelocal {
	append using "nostate_`p'.dta"
	}
drop in 1

order dropstate
destring dropstate, replace

label define yaxis ///
1 "Andaman and Nicobar" ///
2 "Andhra Pradesh" ///
3 "Arunachal Pradesh" ///
4 "Assam" ///
5 "Bihar" ///
6 "Chandigarh" ///
7 "Chhattisgarh" ///
8 "Dadra and Nagar Haveli" ///
9 "Daman and Diu" ///
10 "Goa" ///
11 "Gujarat" ///
12 "Haryana" ///
13 "Himachal Pradesh" ///
14 "Jammu and Kashmir" ///
15 "Jharkhand" ///
16 "Karnataka" ///
17 "Kerala" ///
18 "Lakshadweep" ///
19 "Madhya Pradesh" ///
20 "Maharashtra" /// 
21 "Manipur" ///
22 "Meghalaya" ///
23 "Mizoram" ///
24 "NCT of Delhi" ///
25 "Nagaland" ///
26 "Odisha" ///
27 "Puducherry" ///
28 "Punjab" ///
29 "Rajasthan" ///
30 "Sikkim" /// 
31 "Tamil Nadu" ///
32 "Telangana" ///
33 "Tripura" ///
34 "Uttar Pradesh" ///
35 "Uttarakhand" ///
36 "West Bengal" 
label values dropstate yaxis

save "nostate.dta", replace

twoway (rcap min95 max95 dropstate, horizontal) ///
	(scatter dropstate estimate, msymbol(oh)) ///
	, scheme(lean1) ///
	legend(off) ///
	xscale(range(-0.25 2.75)) xlabel(-0.25(0.50) 2.75) xtitle("95% Confidence Interval") ///
	xline(0, lpattern(solid)) ///
	yscale(range(1 36)) yscale(reverse) ylabel(1(1)36, valuelabel labsize(vsmall)) ytick(1(1)36) ytitle("Excluded State") 
graph export dropstate.png, as(png) width(2500) replace
cap graph close graph

********************************************************************************
********************************************************************************
********************************************************************************

/*Figure A.5: Exclude Colonial Provinces*/

cd "$cleandata\"
use conflictexposure, clear
cd "$output"

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

gen dprov=""
gen beta=.
gen uci=.
gen lci=.
gen rowno=_n

codebook fs1931
levelsof fs1931, local(levels)
local i=0
foreach l of local levels {
	local i=`i'+1
	di "`l'"
	qui xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis' if fs1931~="`l'", r beta
		replace dprov="`l'" if rowno==`i'
		replace beta=_b[Land_250_1757] if rowno==`i'
		replace uci=beta+1.96*_se[Land_250_1757] if rowno==`i'
		replace lci=beta-1.96*_se[Land_250_1757] if rowno==`i'
}
keep rowno dprov beta uci lci
sort rowno
drop if dprov==""

label define yaxis ///
1 "Ajmer Merwara" ///
2 "Assam" ///
3 "Baroda" ///
4 "Bengal" ///
5 "Bihar and Orissa" ///
6 "Bombay Presidency" ///
7 "Central India Agency" ///
8 "Central Province and Berar" ///
9 "Coorg" ///
10 "Dadra and Nagar Haveli" ///
11 "Daman" ///
12 "Delhi" ///
13 "Goa" ///
14 "Gwalior" ///
15 "Hyderabad" ///
16 "Jammu and Kashmir" ///
17 "Karaikal" ///
18 "Madras Presidency" ///
19 "Mahe" ///
20 "Mysore" ///
21 "Naga Tribes" ///
22 "Pondicherryry" ///
23 "Punjab" ///
24 "Rajputana Agency" ///
25 "Sikkim" ///
26 "Singhpos" ///
27 "United Province of Agra and Oudh" ///
28 "Western India State Agency" ///
29 "Yanam" 
label values rowno yaxis

twoway (rcap lci uci rowno, horizontal) ///
	(scatter rowno beta, msymbol(oh)) ///
	, scheme(lean1) ///
	legend(off) ///
	xscale(range(-0.25 2.75)) xlabel(-0.25(0.50) 2.75) xtitle("95% Confidence Interval") ///
	xline(0, lpattern(solid)) ///
	yscale(range(1 29)) yscale(reverse) ylabel(1(1)29, valuelabel labsize(vsmall)) ///
	ytick(1(1)29) ytitle("Excluded Province") 
graph export dropprovince.png, as(png) width(2500) replace
cap graph close graph

********************************************************************************
********************************************************************************
********************************************************************************

/*Figure A.6: Yearly Luminosity Data*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

forvalues t=1992(1)2010 {
	qui xi: reg lnlights`t'_001 Land_250_1757 `controls_gis' i.state_gadm lnpdgpd1990, r 
	parmest, le(95) sa("year_`t'.dta", replace)
}

forvalues t=1992(1)2010 {
	use "year_`t'.dta", clear
	gen N=_n
	keep if N==1
	gen year="`t'"
	keep parm estimate min95 max95 year
	save, replace
}

use "year_1992.dta", clear
forvalues t=1992(1)2010 {
	append using "year_`t'.dta"
	}
drop in 1

order year
destring year, replace

save "year.dta", replace

twoway (rcap min95 max95 year, horizontal) ///
	(scatter year estimate, msymbol(oh)) ///
	, scheme(lean1) ///
	legend(off) ///
	xscale(range(-0.25 3.25)) xlabel(-0.25(0.50) 3.25) xtitle("95% Confidence Interval") ///
	xline(0, lpattern(solid)) ///
	ysc(reverse) yscale(range(1992 2010)) ylabel(1992(1) 2010) ytitle("Year")
graph export year.png, as(png) width(2500) replace
cap graph close graph

********************************************************************************
********************************************************************************
********************************************************************************

/*Figure A.7: Convex Hull Example: Pre-Colonial Land Battles Involving Shah Jahan*/

/*Map made in ArcGIS*/

********************************************************************************
********************************************************************************
********************************************************************************

/*Figure A.8: Cost Distance from Khyber Pass*/

/*See code for Figure A9*/

********************************************************************************
********************************************************************************
********************************************************************************

/*Figure A.9: Khyber Proximity IV*/

use "$cleandata\conflictexposure.dta", clear

preserve	
	cd "$maps"
	cap erase james1.dta				
	cap erase jamesco1.dta
	shp2dta using IND_adm2, data(james1) coord(jamesco1) genid(geoid)
	use james1.dta, clear
	cd "$cleandata"
	isid geoid
	rename NAME_1 state_gadm
	rename NAME_2 district_gadm
	keep state_gadm district_gadm geoid latitude longitude
	sort state_gadm district_gadm 
	saveold jamestemp, replace
restore

preserve
	cd "$cleandata"
	xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 , r beta
	keep if e(sample)
		
	sort state_gadm district_gadm 
	joinby state_gadm district_gadm using jamestemp
	cd "$maps"
	spmap khyberrsq using "jamesco1", id(geoid) ///
	legend(pos(4) region(c(white))) title("") clm(q) cln(10) fc(Greys2) 
	cd "$output"
	graph export khyberrsqmap.png, as(png) width(2500) replace
	graph close graph

	cd "$maps"
	spmap instrument using "jamesco1", id(geoid) ///
	legend(pos(4) region(c(white))) title("") clm(q) cln(10) fc(Greys2) 
	cd "$output"
	graph export instrumentmaprsq.png, as(png) width(2500) replace
	graph close graph
restore

********************************************************************************
********************************************************************************
********************************************************************************

/*Figure A.10: Locations of Conflicts Fought By Invaders from Central Asia, 1000-1757*/

/*Map made in ArcGIS*/

********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************

/*ADDITIONAL RESULTS IN FOOTNOTES OR TEXT*/

********************************************************************************
********************************************************************************
********************************************************************************

/*Section 5.1: Compute Standardized Beta from Banerjee-Iyer 2005, Table 1, Column 1*/

cd "$output"
use "$rawdata\yld_sett_aug03.dta", clear

/*Regression based on Banerjee-Iyer do-file "yldinv_main.do"*/

cap log close
log using section5_1_banerjeeiyer, replace

xi i.year i.state i.nbcluster

regress lyld p_nland brule1 alt totrain so_black so_red so_all lat coastal brule1 _Iyear*, beta

cap log close

********************************************************************************
********************************************************************************
********************************************************************************

/*Footnote: Exclude Districts for which Conflict Exposure=0*/

cd "$cleandata\"
use conflictexposure, clear
cd "$output"

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

drop if Land_250_1757==0

cap erase footnotes_nonzero.txt
cap erase footnotes_nonzero.xml

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990, r beta
outreg2 using footnotes_nonzero, keep(Land_250_1757) excel nocon append

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm, r beta
outreg2 using footnotes_nonzero, keep(Land_250_1757) excel nocon append

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis', r beta
outreg2 using footnotes_nonzero, keep(Land_250_1757) excel nocon append
cap erase footnotes_nonzero.txt	

********************************************************************************
********************************************************************************
********************************************************************************

/*Footnote: Quadratics for Geographic Controls*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

foreach var of varlist `controls_gis' {
	gen sqcont_`var'=`var'^2
}

cap erase footnotes_quadraticgeog.txt
cap erase footnotes_quadraticgeog.xml

xi: reg lnlights_001 Land_250_1757 lnpdgpd1990 i.state_gadm `controls_gis' sqcont_*, r beta
outreg2 using footnotes_quadraticgeog, keep(Land_250_1757) excel nocon append
cap erase footnotes_quadraticgeog.txt

********************************************************************************
********************************************************************************
********************************************************************************

/*Footnote: 1857 as Cutoff for Colonial Sub-Periods*/

cd "$output"
use "$cleandata\conflictexposure.dta", clear

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

cap erase footnotes_post1757conflictalt.txt
cap erase footnotes_post1757conflictalt.xml

xi: reg lnlights_001 Land_250_1757 	Land_250_1758_1859 lnpdgpd1990 i.state_gadm `controls_gis', r beta
outreg2 using footnotes_post1757conflictalt, keep(Land_250_1757) excel nocon append

xi: reg lnlights_001 Land_250_1757 Land_250_1860_1947 lnpdgpd1990 i.state_gadm `controls_gis', r beta
outreg2 using footnotes_post1757conflictalt, keep(Land_250_1757) excel nocon append	

xi: reg lnlights_001 Land_250_1757 Land_250_1758_1859 Land_250_1860_1947 lnpdgpd1990 i.state_gadm `controls_gis', r beta
outreg2 using footnotes_post1757conflictalt, keep(Land_250_1757) excel nocon append	
cap erase footnotes_post1757conflictalt.txt

********************************************************************************
********************************************************************************
********************************************************************************

/*Footnote: Distance to Presidency City*/

cd "$cleandata\"
use conflictexposure, clear
cd "$output"

local controls_gis "latitude_gadm longitude_gadm altit nprug precip ramank dryrice wrice wheat kmal"
drop if district_gadm=="Nicobar Islands" | district_gadm=="South Andaman" | district_gadm=="North and Middle Andaman" | district_gadm=="Lakshadweep"

cap erase footnotes_presidency.txt
cap erase footnotes_presidency.xml

xi: reg lnlights_001 Land_250_1757 dpresid lnpdgpd1990 , r beta
outreg2 using footnotes_presidency, keep(Land_250_1757 dpresid) excel nocon append

xi: reg lnlights_001 Land_250_1757 dpresid lnpdgpd1990 i.state_gadm, r beta
outreg2 using footnotes_presidency, keep(Land_250_1757 dpresid) excel nocon append

xi: reg lnlights_001 Land_250_1757 dpresid lnpdgpd1990 i.state_gadm `controls_gis', r beta
outreg2 using footnotes_presidency, keep(Land_250_1757 dpresid) excel nocon append

xi: reg lnlights_001 Land_250_1757 dpresiddel lnpdgpd1990 , r beta
outreg2 using footnotes_presidency, keep(Land_250_1757 dpresiddel) excel nocon append

xi: reg lnlights_001 Land_250_1757 dpresiddel lnpdgpd1990 i.state_gadm, r beta
outreg2 using footnotes_presidency, keep(Land_250_1757 dpresiddel) excel nocon append

xi: reg lnlights_001 Land_250_1757 dpresiddel lnpdgpd1990 i.state_gadm `controls_gis', r beta
outreg2 using footnotes_presidency, keep(Land_250_1757 dpresiddel) excel nocon append
cap erase footnotes_presidency.txt
